<template>
  <div class="app-container"
       v-loading.fullscreen.lock="downLoading"
       element-loading-text="下载中"
       element-loading-spinner="el-icon-loading"
       element-loading-background="rgba(0, 0, 0, 0.8)">
        <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
          <el-form-item label="模板名称" prop="templateName">
            <el-input
              v-model="queryParams.templateName"
              placeholder="请输入模板名称"
              clearable
              size="small"
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['oa:template:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['oa:template:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['oa:template:remove']"
        >删除
        </el-button>
      </el-col>
      <!--      <el-col :span="1.5">-->
      <!--        <el-button-->
      <!--          type="warning"-->
      <!--          plain-->
      <!--          icon="el-icon-download"-->
      <!--          size="mini"-->
      <!--          @click="handleExport"-->
      <!--          v-hasPermi="['oa:template:export']"-->
      <!--        >导出</el-button>-->
      <!--      </el-col>-->
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="templateList" :header-cell-style="{'text-align':'center'}" style="width: 100%"
              @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column label="序号" align="left" width="50">
        <template slot-scope="scope">
          <span>{{ scope.$index + (queryParams.pageNum - 1) * queryParams.pageSize + 1 }} </span>
        </template>
      </el-table-column>
      <el-table-column label="模板" align="left" prop="templateName">
        <template slot-scope="scope">
<!--          <el-link v-if="scope.row.fileUrl"  type="primary" :href="scope.row.fileUrl" target="_blank">-->
<!--            {{ scope.row.templateName }}-->
<!--          </el-link>-->
          <el-link v-if="scope.row.fileUrl"  type="primary"  @click="uploadFile(scope.row)">
            {{ scope.row.templateName }}
          </el-link>
          <el-link v-else type="primary">{{ scope.row.templateName }}</el-link>
        </template>
      </el-table-column>
      <el-table-column label="发布版本" align="center" prop="versionCode"/>
      <el-table-column label="修订日期" align="center" prop="reviseTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.reviseTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="发布日期" align="center" prop="createTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.createTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['oa:template:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-document"
            @click="handleUpload(scope.row)"
          >附件
          </el-button>
          <el-button
            size="mini"
            type="text"
            class="del-btn"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['oa:template:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改模板管理对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" :append-to-body="true" :close-on-click-modal="false"
               :destroy-on-close="true">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="模板" prop="templateName">
          <el-input v-model="form.templateName" maxlength="64" show-word-limit placeholder="请输入模板"/>
        </el-form-item>
        <el-form-item label="发布版本" prop="versionCode">
          <el-input v-model="form.versionCode" maxlength="64" show-word-limit placeholder="请输入发布版本"/>
        </el-form-item>
        <el-form-item label="修订日期" prop="reviseTime">
          <el-date-picker
            style="width: 100%"
            clearable size="small"
            v-model="form.reviseTime"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="选择修订日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="附件">
          <minio-upload v-model="form.fileUrl" :limit="1" :fileType="[`pdf`, 'xls', 'xlsx', 'ppt', 'pptx','doc','docx']"></minio-upload>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <!-- 附件窗体 -->
    <el-dialog :title="title" :visible.sync="uploadFlag" width="500px" :append-to-body="true"
               :close-on-click-modal="false"
               :destroy-on-close="true">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="附件">
          <!--          <fileUpload v-model="form.fileUrl" :limit="1" :fileType="[`pdf`]"/>-->
          <minio-upload v-model="form.fileUrl" :limit="1" :fileType="['xls', 'xlsx', 'ppt', 'pptx','doc','docx']"></minio-upload>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {listTemplate, getTemplate, delTemplate, addTemplate, updateTemplate} from "@/api/oa/template";
import minioUpload from '@/components/FileUpload/minio'


export default {
  name: "Template",
  components: {minioUpload},
  data() {
    return {
      // 按钮loading
      buttonLoading: false,
      // 遮罩层
      loading: true,
      downLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 模板管理表格数据
      templateList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        templateName: undefined,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        id: [
          {required: true, message: "不能为空", trigger: "blur"}
        ],
        templateName: [
          {required: true, message: "模板不能为空", trigger: "blur"}
        ],
        versionCode: [
          {required: true, message: "发布版本不能为空", trigger: "blur"}
        ],
        reviseTime: [
          {required: true, message: "修订日期不能为空", trigger: "blur"}
        ],
      },
      uploadFlag: false
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询模板管理列表 */
    getList() {
      this.loading = true;
      listTemplate(this.queryParams).then(response => {
        this.templateList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.uploadFlag = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: undefined,
        templateName: undefined,
        versionCode: undefined,
        reviseTime: undefined,
        fileUrl: undefined,
        createBy: undefined,
        createTime: undefined,
        updateBy: undefined,
        updateTime: undefined,
        delFlag: undefined
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加模板管理";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.loading = true;
      this.reset();
      const id = row.id || this.ids
      getTemplate(id).then(response => {
        this.loading = false;
        this.form = response.data;
        this.open = true;
        this.title = "修改模板管理";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          this.buttonLoading = true;
          if (this.form.id != null) {
            updateTemplate(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.uploadFlag = false;
              this.getList();
            }).finally(() => {
              this.buttonLoading = false;
            });
          } else {
            addTemplate(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            }).finally(() => {
              this.buttonLoading = false;
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删？').then(() => {
        this.loading = true;
        return delTemplate(ids);
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).finally(() => {
        this.loading = false;
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('oa/template/export', {
        ...this.queryParams
      }, `template_${new Date().getTime()}.xlsx`)
    },
    handleUpload(row) {
      this.loading = true;
      this.reset();
      const id = row.id || this.ids
      getTemplate(id).then(response => {
        this.loading = false;
        this.form = response.data;
        this.uploadFlag = true;
        this.title = "上传附件";
      });
    },
    uploadFile(item){
      console.log(item)
      if (!item) {
        return;
      }
      this.downLoading = true;
      this.downFile(item.fileUrl, item.templateName);
      this.downLoading = false;
    },
  }
};
</script>
